@@ -1,9 +1,9 @@
 #!/usr/bin/perl
-# $Header: /usr/local/CVS/Perl-Metrics-Simple/t/test_files/package_no_subs.pl,v 1.3 2006/09/24 16:22:35 matisse Exp $
-# $Revision: 1.3 $
+# $Header: /usr/local/CVS/Perl-Metrics-Simple/t/test_files/package_no_subs.pl,v 1.4 2006/11/23 22:25:48 matisse Exp $
+# $Revision: 1.4 $
 # $Author: matisse $
 # $Source: /usr/local/CVS/Perl-Metrics-Simple/t/test_files/package_no_subs.pl,v $
-# $Date: 2006/09/24 16:22:35 $
+# $Date: 2006/11/23 22:25:48 $
 ###############################################################################
 
 package Hello::Dolly;
@@ -11,6 +11,7 @@ package Hello::Dolly;
 use strict;
 use warnings;
 
+START:
 print "Hello world.\n";
 print "I have a package.\n";
 print "I have no subs.\n";
@@ -18,5 +19,6 @@ print "I have no subs.\n";
 for ( 1..5 ) {
     print "$_\n";
 }
+goto START;
 
 exit;
\ No newline at end of file
